@@ -13,13 +13,20 @@
 #'   progression, stasis, and retrogression).
 #' @param matR The reproductive component of a matrix population model (i.e., a
 #'   square projection matrix only reflecting transitions due to reproduction;
-#'   either sexual, clonal, or both).
+#'   either sexual, clonal, or both). If \code{matR} is not provided, it will be
+#'   constructed by summing \code{matF} and \code{matC}.
+#' @param matF The matrix reflecting sexual reproduction. If provided
+#'   without \code{matC}, \code{matC} is assumed to be a zero matrix. If
+#'   \code{matR} is provided, this argument is ignored.
+#' @param matC The matrix reflecting clonal (asexual) reproduction.
+#'   If provided without \code{matF}, \code{matF} is assumed to be a zero
+#'   matrix. If \code{matR} is provided, this argument is ignored.
 #' @param method The method used to calculate generation time. Defaults to "R0".
 #'   See Details for explanation of calculations.
 #' @param ... Additional arguments passed to \code{net_repro_rate} when
 #'   \code{method = "R0"} or \code{mpm_to_*} when \code{method = "cohort"}.
-#'   Ignored when \code{method = "age_diff"}
-#'
+#'   Ignored when \code{method = "age_diff"}.
+
 #' @details
 #' There are multiple definitions of generation time, three of which are
 #' implemented by this function:
@@ -59,7 +66,7 @@
 #'
 #' @references Bienvenu, F. & Legendre, S. 2015. A New Approach to the
 #'   Generation Time in Matrix Population Models. The American Naturalist 185
-#'   (6): 834–843. doi:10.1086/681104.
+#'   (6): 834–843. <doi:10.1086/681104>.
 #'
 #' Caswell, H. 2001. Matrix Population Models: Construction,
 #'   Analysis, and Interpretation. Sinauer Associates; 2nd edition. ISBN:
@@ -73,6 +80,7 @@
 #'
 #' # calculate generation time
 #' gen_time(matU = mpm1$matU, matR = mpm1$matF) # defaults to "R0" method
+#' gen_time(matU = mpm1$matU, matF = mpm1$matF) # defaults to "R0" method
 #' gen_time(matU = mpm1$matU, matR = mpm1$matF, method = "age_diff")
 #' gen_time(
 #'   matU = mpm1$matU, matR = mpm1$matF, method = "cohort", lx_crit =
@@ -80,7 +88,12 @@
 #' )
 #'
 #' @export gen_time
-gen_time <- function(matU, matR, method = c("R0", "age_diff", "cohort"), ...) {
+gen_time <- function(matU, matR = NULL, matF = NULL, matC = NULL, 
+                     method = c("R0", "age_diff", "cohort"), ...) {
+  
+  # Call the helper function to construct matR if not provided
+  matR <- process_fertility_inputs(matR, matF, matC)
+  
   method <- match.arg(method)
   # leave remaining arg validation to functions that depend on them
 
