@@ -60,8 +60,11 @@ perturb_matrix <- function(matA, pert = 1e-6, type = "sensitivity",
   } else {
     statfun <- try(match.fun(demog_stat), silent = TRUE)
     if (inherits(statfun, "try-error")) {
-      stop(strwrap(prefix = " ", initial = "", "demog_stat must be 'lambda' or the name of a
-                   function that returns a single numeric value.\n"), call. = FALSE)
+      stop(strwrap(
+        prefix = " ", initial = "",
+        "demog_stat must be 'lambda' or the name of a
+     function that returns a single numeric value.\n"
+      ), call. = FALSE)
     }
   }
 
